@@ -36,9 +36,7 @@ fi
 # Safety check: verify this is the last partition
 LAST_PART_NUM=$(parted "$ROOT_DEV" -ms unit s p 2>/dev/null | tail -n 1 | cut -f 1 -d:)
 if [ "$LAST_PART_NUM" != "$PART_NUM" ]; then
-   echo "ERROR: $ROOT_PART (partition $PART_NUM) is not the last partition (last is $LAST_PART_NUM)"
-   echo "Cannot safely expand - manual intervention required"
-   exit 1
+   echo "WARNING: $ROOT_PART (partition $PART_NUM) is not the last partition (last is $LAST_PART_NUM)"
 fi
 
 # Check if growpart is available
